@@ -56,6 +56,7 @@ struct _GeditDocumentSaver
 	GObject object;
 
 	/*< private >*/
+	GFileInfo		 *info;
 	GeditDocument		 *document;
 	gboolean		  used;
 
@@ -85,9 +86,7 @@ struct _GeditDocumentSaverClass
 
 	/* VTable */
 	void			(* save)		(GeditDocumentSaver *saver,
-							 time_t              old_mtime);
-	const gchar *		(* get_content_type)	(GeditDocumentSaver *saver);
-	time_t			(* get_mtime)		(GeditDocumentSaver *saver);
+							 GTimeVal           *old_mtime);
 	goffset			(* get_file_size)	(GeditDocumentSaver *saver);
 	goffset			(* get_bytes_written)	(GeditDocumentSaver *saver);
 };
@@ -120,12 +119,14 @@ void			 gedit_document_saver_saving		(GeditDocumentSaver *saver,
 								 gboolean            completed,
 								 GError             *error);
 void			 gedit_document_saver_save		(GeditDocumentSaver  *saver,
-								 time_t               old_mtime);
+								 GTimeVal            *old_mtime);
 
 #if 0
 void			 gedit_document_saver_cancel		(GeditDocumentSaver  *saver);
 #endif
 
+GeditDocument		*gedit_document_saver_get_document	(GeditDocumentSaver  *saver);
+
 const gchar		*gedit_document_saver_get_uri		(GeditDocumentSaver  *saver);
 
 /* If backup_uri is NULL no backup will be made */
@@ -133,15 +134,13 @@ const gchar		*gedit_document_saver_get_backup_uri	(GeditDocumentSaver  *saver);
 void			*gedit_document_saver_set_backup_uri	(GeditDocumentSaver  *saver,
 							 	 const gchar         *backup_uri);
 
-const gchar		*gedit_document_saver_get_content_type	(GeditDocumentSaver  *saver);
-
-time_t			 gedit_document_saver_get_mtime		(GeditDocumentSaver  *saver);
-
 /* Returns 0 if file size is unknown */
 goffset			 gedit_document_saver_get_file_size	(GeditDocumentSaver  *saver);
 
 goffset			 gedit_document_saver_get_bytes_written	(GeditDocumentSaver  *saver);
 
+GFileInfo		*gedit_document_saver_get_info		(GeditDocumentSaver  *saver);
+
 G_END_DECLS
 
 #endif  /* __GEDIT_DOCUMENT_SAVER_H__  */
