@@ -36,6 +36,7 @@
 #include <libxml/xmlreader.h>
 #include "gedit-metadata-manager.h"
 #include "gedit-debug.h"
+#include "gedit-dirs.h"
 
 /*
 #define GEDIT_METADATA_VERBOSE_DEBUG	1
@@ -93,15 +94,15 @@ item_free (gpointer data)
 static void
 gedit_metadata_manager_arm_timeout (void)
 {
-	if (gedit_metadata_manager->timeout_id)
-		return;
-		
-	gedit_metadata_manager->timeout_id = 
-		g_timeout_add_full (G_PRIORITY_DEFAULT_IDLE,
-				    2000, /* 2 sec */
-				    (GSourceFunc)gedit_metadata_manager_save,
-				    NULL,
-				    NULL);
+	if (gedit_metadata_manager->timeout_id == 0)
+	{
+		gedit_metadata_manager->timeout_id = 
+			g_timeout_add_seconds_full (G_PRIORITY_DEFAULT_IDLE,
+						    2,
+						    (GSourceFunc)gedit_metadata_manager_save,
+						    NULL,
+						    NULL);
+	}
 }
 
 static gboolean
@@ -220,20 +221,22 @@ parseItem (xmlDocPtr doc, xmlNodePtr cur)
 static gchar *
 get_metadata_filename (void)
 {
-	const gchar *home;
+	gchar *cache_dir;
+	gchar *metadata;
 
-	home = g_get_home_dir ();
-	if (home == NULL)
-	{
-		g_warning ("Could not get home directory\n");
-		return NULL;
-	}
+	cache_dir = gedit_dirs_get_user_cache_dir ();
 
-	return g_build_filename (home, ".gnome2", METADATA_FILE, NULL);
+	metadata = g_build_filename (cache_dir,
+				     METADATA_FILE,
+				     NULL);
+
+	g_free (cache_dir);
+
+	return metadata;
 }
 
 static gboolean
-load_values ()
+load_values (void)
 {
 	xmlDocPtr doc;
 	xmlNodePtr cur;
@@ -488,7 +491,7 @@ get_oldest (const gchar *key, const gpointer value, const gchar ** key_to_remove
 }
 
 static void
-resize_items ()
+resize_items (void)
 {
 	while (g_hash_table_size (gedit_metadata_manager->items) > MAX_ITEMS)
 	{
@@ -536,7 +539,18 @@ gedit_metadata_manager_save (gpointer data)
 	file_name = get_metadata_filename ();
 	if (file_name != NULL)
 	{
-		xmlSaveFormatFile (file_name, doc, 1);
+		gchar *cache_dir;
+		int res;
+
+		/* make sure the cache dir exists */
+		cache_dir = gedit_dirs_get_user_cache_dir ();
+		res = g_mkdir_with_parents (cache_dir, 0755);
+		if (res != -1)
+		{
+			xmlSaveFormatFile (file_name, doc, 1);
+		}
+
+		g_free (cache_dir);
 		g_free (file_name);
 	}
 
