@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.h 6819 2009-01-07 14:56:55Z icq $
+ * $Id$
  */
 
 #ifndef __GEDIT_WINDOW_H__
@@ -169,11 +169,10 @@ GeditWindow	*_gedit_window_move_tab_to_new_window	(GeditWindow         *window,
 							 GeditTab            *tab);
 gboolean	 _gedit_window_is_removing_tabs		(GeditWindow         *window);
 
-G_CONST_RETURN gchar
-		*_gedit_window_get_default_path 	(GeditWindow         *window);
+GFile		*_gedit_window_get_default_location 	(GeditWindow         *window);
 
-void		 _gedit_window_set_default_path 	(GeditWindow         *window,
-							 const gchar         *uri);
+void		 _gedit_window_set_default_location 	(GeditWindow         *window,
+							 GFile               *location);
 
 void		 _gedit_window_set_saving_session_state	(GeditWindow         *window,
 							 gboolean             saving_session);
@@ -191,6 +190,8 @@ void		 _gedit_recent_add			(GeditWindow	     *window,
 void		 _gedit_recent_remove			(GeditWindow         *window,
 							 const gchar         *uri);
 
+GtkWidget 	*_gedit_window_get_menu_bar		(GeditWindow         *window);
+
 G_END_DECLS
 
 #endif  /* __GEDIT_WINDOW_H__  */
