@@ -1051,20 +1051,28 @@ model_sort_default (FileBrowserNode * node1, FileBrowserNode * node2)
 	f2 = NODE_IS_DUMMY (node2);
 
 	if (f1 && f2)
+	{
 		return 0;
-	else if (f1)
-		return -1;
-	else if (f2)
-		return 1;
+	}
+	else if (f1 || f2)
+	{
+		return f1 ? -1 : 1;
+	}
 
 	f1 = NODE_IS_DIR (node1);
 	f2 = NODE_IS_DIR (node2);
 
-	if (f1 != f2) {
-		if (f1)
-			return -1;
-		else
-			return 1;
+	if (f1 != f2)
+	{
+		return f1 ? -1 : 1;
+	}
+
+	f1 = NODE_IS_HIDDEN (node1);
+	f2 = NODE_IS_HIDDEN (node2);
+
+	if (f1 != f2)
+	{
+		return f2 ? -1 : 1;
 	}
 
 	return collate_nodes (node1, node2);
